Using the ricecooker framework
==============================

<!-- Note this page exists for backward compatibility (since we sent this link)
    to partners, we don't want them to hit a 404. -->

The following links will get you started with content integration process in no time!

 - [Installation](installation.html): info about install the `ricecooker` package
   and system prerequisites (5–20 mins)
 - [Getting started](tutorial/gettingstarted.html): upload your first channel to
   Kolibri Studio and import it in Kolibri (10 mins)
 - For more info see the [ricecooker docs main page](index.html) 📚.
